@@ -12,4 +12,12 @@ from pyaniml.core.infrastructure import Infrastructure
 from pyaniml.core.method import Method
 from pyaniml.core.method import Device
 from pyaniml.core.method import Author
+from pyaniml.core.method import Software
 from pyaniml.core.result import Result
+from pyaniml.core.unit import Unit
+from pyaniml.core.unit import SIUnit
+from pyaniml.core.enums import DataTypeChoices
+from pyaniml.core.enums import Dependencies
+from pyaniml.core.enums import DataTypes
+from pyaniml.core.enums import Purposes
+from pyaniml.core.enums import SIUnits
