@@ -1,8 +1,9 @@
 from dataclasses import dataclass
+
 from pyaniml.utility import element, SchemaBase
-from pyaniml.core.experimentstep import ExperimentStepSet
-from pyaniml.core.sample import SampleSet
-from pyaniml.core.sets import AuditTrailEntrySet
+from pyaniml.core.experimentstep import ExperimentStepSet, ExperimentStep
+from pyaniml.core.sample import SampleSet, Sample
+from pyaniml.core.sets import AuditTrailEntrySet, SignatureSet
 
 
 @dataclass
@@ -13,30 +14,30 @@ class AnIMLDocument(SchemaBase):
         name = "AnIML"
         # namespace = "urn:org:astm:animl:schema:core:draft:0.90"
 
-    samples: SampleSet = element(
-        name="SampleSet", default=SampleSet
-    )
+    sample_set: SampleSet = element(name="SampleSet", default=SampleSet)
 
-    experiment_steps: ExperimentStepSet = element(
+    experiment_step_set: ExperimentStepSet = element(
         name="ExperimentStepSet", default=ExperimentStepSet
     )
 
-    audit_tray_entries: AuditTrailEntrySet = element(
+    audit_trail_entry_set: AuditTrailEntrySet = element(
         name="AuditTrailEntrySet", default=AuditTrailEntrySet
     )
 
-    def add_sample(self, sample):
+    signature_set: SignatureSet = element(name="SignatureSet", default=SignatureSet)
+
+    def add_sample(self, sample: Sample):
         """Adds a sample to the sample set
 
         Args:
             sample (Sample): Container describing a sample
         """
-        self.samples.add_sample(sample)
+        self.sample_set.add_sample(sample)
 
-    def add_experiment_step(self, experiment_step):
+    def add_experiment_step(self, experiment_step: ExperimentStep):
         """Adds an experiment step to the experiment step set
 
         Args:
             experiment_step (ExperimentStep): Container describing an experiment step
         """
-        self.experiment_steps.add_experiment_step(experiment_step)
+        self.experiment_step_set.add_experiment_step(experiment_step)
